@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # designateclient documentation build configuration file
 
@@ -6,7 +5,12 @@
 
 # Add any Sphinx extension module names here, as strings. They can be extensions
 # coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinx.ext.autodoc', 'sphinx.ext.viewcode', 'openstackdocstheme']
+extensions = [
+    'sphinx.ext.autodoc',
+    'sphinx.ext.viewcode',
+    'sphinxcontrib.apidoc',
+    'openstackdocstheme',
+    'cliff.sphinxext']
 
 # openstackdocstheme options
 openstackdocs_repo_name = 'openstack/python-designateclient'
@@ -14,6 +18,16 @@ openstackdocs_bug_project = 'python-designateclient'
 openstackdocs_bug_tag = ''
 html_theme = 'openstackdocs'
 
+apidoc_module_dir = '../../designateclient'
+apidoc_output_dir = 'reference/api'
+apidoc_excluded_paths = [ 'tests/*', 'functionaltests/*', 'hacking/*' ]
+apidoc_separate_modules = True
+
+autodoc_exclude_modules = [
+  'designateclient.tests.*',
+  'designateclient.functionaltests.*',
+  'designateclient.hacking.*']
+
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['_templates']
 
@@ -24,7 +38,7 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-copyright = u'2012, Managed I.T. 2013-2014, Hewlett-Packard Development Company, L.P.'
+copyright = '2012, Managed I.T. 2013-2014, Hewlett-Packard Development Company, L.P.'
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
